==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/outputs/RuleGroupRuleStatementSizeConstraintStatement.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property comparisonOperator The operator to use to compare the request part to the size setting. Valid values include: `EQ`, `NE`, `LE`, `LT`, `GE`, or `GT`.
 * @property fieldToMatch The part of a web request that you want AWS WAF to inspect. See Field to Match below for details.
 * @property size The size, in bytes, to compare to the request part, after any transformations. Valid values are integers between 0 and 21474836480, inclusive.
 * @property textTransformations Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection.
 * At least one required.
 * See Text Transformation below for details.
 */
public data class RuleGroupRuleStatementSizeConstraintStatement(
    public val comparisonOperator: String,
    public val fieldToMatch: RuleGroupRuleStatementSizeConstraintStatementFieldToMatch? = null,
    public val size: Int,
    public val textTransformations:
    List<RuleGroupRuleStatementSizeConstraintStatementTextTransformation>,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.wafv2.outputs.RuleGroupRuleStatementSizeConstraintStatement):
            RuleGroupRuleStatementSizeConstraintStatement =
            RuleGroupRuleStatementSizeConstraintStatement(
                comparisonOperator = javaType.comparisonOperator(),
                fieldToMatch = javaType.fieldToMatch().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.RuleGroupRuleStatementSizeConstraintStatementFieldToMatch.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                size = javaType.size(),
                textTransformations = javaType.textTransformations().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.RuleGroupRuleStatementSizeConstraintStatementTextTransformation.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/outputs/RuleGroupRuleStatementSizeConstraintStatement.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property comparisonOperator The operator to use to compare the request part to the size setting. Valid values include: `EQ`, `NE`, `LE`, `LT`, `GE`, or `GT`.
 * @property fieldToMatch The part of a web request that you want AWS WAF to inspect. See Field to Match below for details.
 * @property size The size, in bytes, to compare to the request part, after any transformations. Valid values are integers between 0 and 21474836480, inclusive.
 * @property textTransformations Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection.
 * At least one required.
 * See Text Transformation below for details.
 */
public data class RuleGroupRuleStatementSizeConstraintStatement(
    public val comparisonOperator: String,
    public val fieldToMatch: RuleGroupRuleStatementSizeConstraintStatementFieldToMatch? = null,
    public val size: Int,
    public val textTransformations: List<RuleGroupRuleStatementSizeConstraintStatementTextTransformation>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.wafv2.outputs.RuleGroupRuleStatementSizeConstraintStatement): RuleGroupRuleStatementSizeConstraintStatement =
            RuleGroupRuleStatementSizeConstraintStatement(
                comparisonOperator = javaType.comparisonOperator(),
                fieldToMatch = javaType.fieldToMatch().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.RuleGroupRuleStatementSizeConstraintStatementFieldToMatch.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                size = javaType.size(),
                textTransformations = javaType.textTransformations().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.RuleGroupRuleStatementSizeConstraintStatementTextTransformation.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}
